package me.mrletsplay.nojs._test;

import java.util.ArrayList;
import java.util.List;

import me.mrletsplay.nojs.action.Action;
import me.mrletsplay.nojs.action.ActionData;
import me.mrletsplay.nojs.action.ActionEvent;
import me.mrletsplay.nojs.action.ActionHandler;
import me.mrletsplay.nojs.component.Component;
import me.mrletsplay.nojs.component.impl.Button;
import me.mrletsplay.nojs.component.impl.Form;
import me.mrletsplay.nojs.component.impl.Group;
import me.mrletsplay.nojs.component.impl.Link;
import me.mrletsplay.nojs.component.impl.Message;
import me.mrletsplay.nojs.component.impl.Text;
import me.mrletsplay.nojs.component.impl.TextInput;
import me.mrletsplay.nojs.page.Page;
import me.mrletsplay.nojs.page.layout.GridLayout;
import me.mrletsplay.nojs.page.layout.HClampLayout;

public class LinksPage implements Page {

	private List<String> links = new ArrayList<>();
	private String error;

	@Override
	public Component getContent() {
		Group linksGroup = new Group()
			.layout(GridLayout.ofColumns(1)
				.gap("4px"));

		for(String s : links) {
			linksGroup.add(
				new Form().add(
					new Link()
						.href(s)
						.text(s)
						.target(Link.Target.BLANK),
					new Button()
						.text("Delete")
				)
				.action(new Action("removeLink")
					.extraData(new ActionData().put("link", s)))
				.layout(new GridLayout()
					.columns("1fr", "auto")
					.gap("4px")
					.vAlignment(GridLayout.VAlignment.START))
			);
		}

		if(links.isEmpty()) {
			linksGroup.add(new Text().text("No links added yet"));
		}

		if(error != null) {
			linksGroup.add(new Message()
				.text(error)
				.type(Message.Type.ERROR));
			error = null;
		}

		return new Group()
			.add(
				new Group().add(
					linksGroup,
					new Form().add(
						new Text().text("Add a new link:"),
						new Group().add(
							new TextInput("linkName").placeholder("Link Name"),
							new TextInput("link").placeholder("Insert link here"),
							new Button().text("Add Link")
						)
						.layout(GridLayout.ofColumns(1)
							.gap("4px"))
					)
					.layout(GridLayout.ofColumns(1).gap("4px"))
					.action(new Action("addLink"))
				)
				.layout(GridLayout.ofColumns(1).gap("10px"))
			)
			.layout(new HClampLayout("200px", "100%", "800px")
				.hAlignment(HClampLayout.HAlignment.CENTER));
	}

	@ActionHandler("addLink")
	public void addLink(ActionEvent event) {
		String link = event.getData("link");
		if(link == null || link.isBlank() || (!link.startsWith("http://") && !link.startsWith("https://"))) {
			error = "Invalid link";
			return;
		}

		links.add(event.getData("link"));
	}

	@ActionHandler("removeLink")
	public void removeLink(ActionEvent event) {
		String link = event.getData("link");
		links.remove(link);
	}

}
