package me.mrletsplay.nojs.component.impl;

import java.util.Objects;

import me.mrletsplay.nojs.component.Component;
import me.mrletsplay.simplehttpserver.dom.html.HtmlElement;

public class TextInput implements Component {

	private String name;
	private String placeholder;
	private String value;
	private boolean hidden;

	public TextInput(String name) {
		Objects.requireNonNull(name, "name");

		this.name = name;
		this.placeholder = "";
		this.value = "";
		this.hidden = false;
	}

	public TextInput placeholder(String placeholder) {
		this.placeholder = placeholder != null ? placeholder : "";
		return this;
	}

	public TextInput value(String value) {
		this.value = value != null ? value : "";
		return this;
	}

	public TextInput hidden(boolean hidden) {
		this.hidden = hidden;
		return this;
	}

	@Override
	public HtmlElement toHtml() {
		HtmlElement input = HtmlElement.of("input");
		input.addClass("input");
		input.setAttribute("name", name);

		if(!placeholder.isEmpty()) {
			input.setAttribute("placeholder", placeholder);
		}

		if(!value.isEmpty()) {
			input.setAttribute("value", value);
		}

		if(hidden) {
			input.setAttribute("hidden");
		}

		return input;
	}

}
